@@ -1,7 +1,7 @@
 package Sah::Schema::Rinci;
 
-our $DATE = '2014-10-30'; # DATE
-our $VERSION = '1.1.69'; # VERSION
+our $DATE = '2014-11-19'; # DATE
+our $VERSION = '1.1.70'; # VERSION
 
 use 5.010001;
 use strict;
@@ -58,6 +58,9 @@ $SCHEMAS{rinci_function} = [hash => {
             _value_prop => {
                 %dh_props,
 
+                # common rinci metadata
+                links => {},
+
                 schema => {},
                 default => {},
                 req => {},
@@ -188,7 +191,7 @@ Sah::Schema::Rinci - Sah schemas for Rinci metadata
 
 =head1 VERSION
 
-This document describes version 1.1.69 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2014-10-30.
+This document describes version 1.1.70 of Sah::Schema::Rinci (from Perl distribution Rinci), released on 2014-11-19.
 
 =head1 HOMEPAGE
 
